@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Nov 25 2001
     copyright            : (C) 2001-2017 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 /*
@@ -48,7 +48,7 @@ enum Optcode {
         S_OPT_PRINT_STYLE, S_OPT_NO_TRAILING_NL, S_OPT_PLUGIN, S_OPT_ABS_CFG_PATH,
         S_OPT_PLUGIN_READFILE, S_OPT_PLUGIN_PARAMETER, S_OPT_LIST_SCRIPTS, S_OPT_CANVAS,
         S_OPT_KEEP_INJECTIONS, S_OPT_FORCE_STDOUT, S_OPT_LATEX_BEAMER, S_OPT_NO_VERSION_INFO,
-        S_OPT_REFORMAT_OPT, S_OPT_RANGE_OPT, S_OPT_BASE16
+        S_OPT_REFORMAT_OPT, S_OPT_RANGE_OPT, S_OPT_BASE16, S_OPT_CATEGORIES
     };
 
 const Arg_parser::Option options[] = {
@@ -63,7 +63,7 @@ const Arg_parser::Option options[] = {
         { 'f', OPT_FRAGMENT,       Arg_parser::no  },
         { 'F', OPT_FORMAT,         Arg_parser::yes },
 
-        { 'h', OPT_HELP,           Arg_parser::no  },
+        { 'h', OPT_HELP,           Arg_parser::maybe  },
         { 'i', OPT_IN,             Arg_parser::yes },
         { 'I', OPT_INC_STYLE,      Arg_parser::no  },
         { 'j', OPT_LNR_LEN,        Arg_parser::yes },
@@ -134,8 +134,8 @@ const Arg_parser::Option options[] = {
         { S_OPT_LIST_SCRIPTS,     OPT_LIST_SCRIPTS,    Arg_parser::yes},
         { S_OPT_CANVAS,           OPT_CANVAS,          Arg_parser::maybe },
         { S_OPT_REFORMAT_OPT,     OPT_REFORMAT_OPT,    Arg_parser::yes },
-        { S_OPT_RANGE_OPT,        OPT_RANGE_OPT,    Arg_parser::yes },
-
+        { S_OPT_RANGE_OPT,        OPT_RANGE_OPT,       Arg_parser::yes },
+        { S_OPT_CATEGORIES,       OPT_CATEGORIES,      Arg_parser::yes },
 
         { 0, 0, Arg_parser::no }
     };
@@ -337,6 +337,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             break;
         case 'h':
             opt_help = true;
+            helpTopic = arg;
             break;
         case 'i':
             inputFileNames.push_back ( arg );
@@ -564,6 +565,9 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
                 StringTools::str2num<unsigned int> ( canvasPaddingWidth, arg, std::dec );
             break;
             
+        case S_OPT_CATEGORIES:
+            categories=arg;
+            break;
         default:
             cerr << "highlight: option parsing failed" << endl;
         }
@@ -983,3 +987,11 @@ int CmdLineOptions::getLineRangeEnd()
 {
     return lineRangeEnd;
 }
+
+const string& CmdLineOptions::getCategories() const {
+    return categories;
+}
+
+const string& CmdLineOptions::getHelpTopic() const {
+    return helpTopic;
+}
