@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Nov 25 2001
     copyright            : (C) 2001-2017 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -125,6 +125,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_COMPAT_SRCLANG   "src-lang"
 #define OPT_COMPAT_LINENUM   "line-number"
 #define OPT_COMPAT_LINEREF   "line-number-ref"
+#define OPT_CATEGORIES       "list-cat"  
 
 using namespace std;
 
@@ -164,7 +165,7 @@ public:
 
     /** \return SVG height*/
     const string& getSVGHeight() const;
-
+    
     /** \return Number of spaces to replace a tab*/
     int getNumberSpaces() const;
 
@@ -363,6 +364,12 @@ public:
     /** \return parameter passed to plugin */
     const string& getPluginParameter() const ;
 
+    /** \return categories sepatated by X to filter scripts in --list-scripts */
+    const string& getCategories() const ;
+    
+    /** \return optional help topic */
+    const string& getHelpTopic() const;
+
     /** \return line number width */
     int getNumberWidth();
 
@@ -419,9 +426,11 @@ private:
            styleInFilename,
            // used to define data directories at runtime
            dataDir;
+           
     // name of indenation scheme
     string indentScheme,
-           pageSize, startNestedLang;
+           pageSize, 
+           startNestedLang;
 
     string baseFont, baseFontSize;
     string docTitle, className;
@@ -473,7 +482,8 @@ private:
     string anchorPrefix;
     string helpLang, encodingName;
 
-    string pluginPath, pluginParameter;
+    string pluginPath, pluginParameter, 
+           categories, helpTopic;
 
     /** list of all input file names */
     vector <string> inputFileNames;
