@@ -3,7 +3,7 @@
                              -------------------
     begin                : Die Apr 23 22:16:35 CEST 2002
     copyright            : (C) 2002-2018 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
 
    Highlight is a universal source code to HTML converter. Syntax highlighting
    is formatted by Cascading Style Sheets. It's possible to easily enhance
@@ -45,7 +45,7 @@ void HLCmdLineApp::printVersionInfo()
 {
     cout << "\n highlight version "
          << HIGHLIGHT_VERSION
-         << "\n Copyright (C) 2002-2018 Andre Simon <andre.simon1 at gmx.de>"
+         << "\n Copyright (C) 2002-2019 Andre Simon <a dot simon at mailbox.org>"
          << "\n\n Argparser class"
          << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
          << "\n\n Artistic Style Classes (3.1)"
@@ -71,7 +71,7 @@ void HLCmdLineApp::printBadInstallationInfo()
          << OPT_DATADIR << ".\n";
 }
 
-int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcard, const string& what, const string&option)
+int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcard, const string& kind, const string& option, const string& categoryFilterList)
 {
     vector <string> filePaths;
     string searchDir = where + wildcard;
@@ -84,73 +84,96 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
         return EXIT_FAILURE;
     }
 
-    cout << "\nInstalled "<< what << " (located in " << where << "):\n\n";
-
-    sort ( filePaths.begin(), filePaths.end() );
-    string temp;
-
-    for ( unsigned int i=0; i< filePaths.size(); i++ ) {
-        temp = ( filePaths[i] ).substr ( where.length() );
-        cout <<temp.substr ( 1, temp.length()- wildcard.length() ) << endl;
-    }
-    cout <<"\nUse the name of the desired "<<what
-         << " with the --" <<option<< " option." << endl;
-
-    if (what=="themes") {
-        cout <<"\nApply --base16 to select a Base16 theme." << endl;
-    }
-         
-    printConfigInfo();
-    
-    return EXIT_SUCCESS;
-}
-
-
-int HLCmdLineApp::printInstalledLanguages()
-{
-    vector <string> filePaths;
-    string wildcard="*.lang";
-    string directory=dataDir.getLangPath();
-    string searchDir = directory + wildcard;
-
-    bool directoryOK = Platform::getDirectoryEntries ( filePaths, searchDir, true );
-    if ( !directoryOK ) {
-        cerr << "highlight: Could not access directory "
-             <<  searchDir
-             << ", aborted.\n";
-        return EXIT_FAILURE;
-    }
-
     sort ( filePaths.begin(), filePaths.end() );
     string suffix, desc;
-    cout << "\nInstalled language definitions"
-         << " (located in " << directory << "):\n\n";
+    Diluculum::LuaValueMap categoryMap;
+    cout << "\nInstalled language definitions";
+    
+    if (categoryFilterList.size())
+        cout << " matching \""<<categoryFilterList<<"\"";
+    
+    cout << " (located in " << where << "):\n\n";
+    int matchedFileCnt=0;
+    std::set<string> categoryNames;
+    std::set<string> categoryFilters;
 
+    istringstream valueStream;
+    string catFilter;
+    valueStream.str ( StringTools::change_case ( categoryFilterList,StringTools::CASE_LOWER ) );
+    while ( getline ( valueStream, catFilter, ';' ) ) {
+        categoryFilters.insert ( catFilter );
+    }
+            
     for ( unsigned int i=0; i< filePaths.size(); i++ ) {
         try {
             Diluculum::LuaState ls;
             highlight::SyntaxReader::initLuaState(ls, filePaths[i],"");
             ls.doFile(filePaths[i]);
             desc = ls["Description"].value().asString();
-            suffix = ( filePaths[i] ).substr ( directory.length() ) ;
+            
+            suffix = ( filePaths[i] ).substr ( where.length() ) ;
             suffix = suffix.substr ( 1, suffix.length()- wildcard.length() );
-            cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
-            int extCnt=0;
-            for (StringMap::iterator it=assocByExtension.begin(); it!=assocByExtension.end(); it++) {
-                if (it->second==suffix ) {
-                    cout << ((++extCnt==1)?" ( ":" ")<<it->first;
-                }
+
+            unsigned int filterOKCnt=categoryFilters.size();
+            if (ls["Categories"].value() !=Diluculum::Nil){
+                filterOKCnt=0;
+
+                categoryMap = ls["Categories"].value().asTable();
+                
+                //TODO: negation
+                for(Diluculum::LuaValueMap::const_iterator it = categoryMap.begin(); it != categoryMap.end(); ++it)
+                {
+                    categoryNames.insert(it->second.asString());
+                    if (categoryFilters.size() && categoryFilters.count(it->second.asString())) {
+                        ++filterOKCnt;
+                    }
+                }     
             }
-            cout << ((extCnt)?" )":"")<<endl;
+           
+            if (filterOKCnt!=categoryFilters.size() && categoryFilters.size() ) continue;
+            
+            matchedFileCnt++;
+            if (kind=="langDef") {
+                cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
+            
+                int extCnt=0;
+                for (StringMap::iterator it=assocByExtension.begin(); it!=assocByExtension.end(); it++) {
+                    if (it->second==suffix ) {
+                        cout << ((++extCnt==1)?" ( ":" ")<<it->first;
+                    }
+                }
+                cout << ((extCnt)?" )":"");
+            } else {
+                cout << setw ( 30 ) <<setiosflags ( ios::left ) <<suffix<<": "<<desc;
+            
+            }
+            cout << endl;
         } catch (std::runtime_error &error) {
-            cout << "Faild to read '" << filePaths[i] << "': " << error.what() << endl;
+            cout << "Failed to read '" << filePaths[i] << "': " << error.what() << endl;
         }
     }
-    cout <<"\nUse name of the desired language"
-         << " with the --" OPT_SYNTAX " option." << endl;
-         
-    printConfigInfo();
-         
+    
+    if (!matchedFileCnt) {
+        cout <<"No files found." << endl;
+    } else {
+        
+        if (!categoryFilters.size()){
+            cout << "\nFound "<<kind<<" categories:\n\n";
+            for (std::set<string>::iterator it=categoryNames.begin(); it!=categoryNames.end(); ++it)
+                std::cout << *it<< ' ';
+            cout << "\n";
+        }
+        
+        cout <<"\nUse name of the desired "<<kind
+            << " with --" << option << ". Filter categories with --list-cat." << endl;
+            
+        if (kind=="theme") {
+            cout <<"\nApply --base16 to select a Base16 theme." << endl;
+        }
+        
+        printConfigInfo();
+    }
+    
     return EXIT_SUCCESS;
 }
 
@@ -400,7 +423,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     dataDir.initSearchDirectories ( dataDirPath );
 
     if ( options.printHelp() ) {
-        Help::printHelp();
+        Help::printHelp(options.getHelpTopic());
         return EXIT_SUCCESS;
     }
 
@@ -410,17 +433,17 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     }
 
     if ( options.showThemes() ) {
-        return printInstalledFiles(dataDir.getThemePath(), "*.theme", "themes", OPT_STYLE) ?EXIT_SUCCESS:EXIT_FAILURE;
+        return printInstalledFiles(dataDir.getThemePath(), "*.theme", "theme", OPT_STYLE, options.getCategories());
     }
     if ( options.showPlugins() ) {
-        return printInstalledFiles(dataDir.getPluginPath(), "*.lua", "plug-ins", OPT_PLUGIN) ?EXIT_SUCCESS:EXIT_FAILURE;
+        return printInstalledFiles(dataDir.getPluginPath(), "*.lua", "plug-in", OPT_PLUGIN, options.getCategories());
     }
 
     //call before printInstalledLanguages!
     loadFileTypeConfig ( "filetypes" );
 
     if ( options.showLangdefs() ) {
-        return printInstalledLanguages();
+        return printInstalledFiles(dataDir.getLangPath(), "*.lang", "langDef", OPT_SYNTAX, options.getCategories());
     }
 
     const vector <string> inFileList=options.getInputFileNames();
