@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sam March 1 2003
     copyright            : (C) 2003 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
